==> hollow-cli-1.3.9.tgz: package/esm/mwMultiEntryHTML.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 24/08/2017 18:42.
 **************************************************/
import { CopyWebpackPlugin, DefinePlugin, ProvidePlugin, HTMLWebpackPlugin } from './plugins';
import { fnBuildCopyFiles, fnBuildExternals, fnBuildHTML } from './util';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var packageMap, plugins, ENV, version, versionTail;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            next();
            packageMap = context.packageMap, plugins = context.plugins, ENV = context.ENV;
            /***********************
             * copy文件到输出目录
             */

            plugins.push(new CopyWebpackPlugin(fnBuildCopyFiles(context.files)));
            /***********************
             * 配置忽略依赖
             */

            context.externals = fnBuildExternals(context.externals);
            version = context.version || packageMap.version || '0.0.0';
            versionTail = ENV.isBeta ? '-beta' : ENV.isDevelopment ? '-dev' : '';
            plugins.push(new DefinePlugin(_objectSpread({
              VERSION: JSON.stringify(version),
              APPLICATION_VERSION: JSON.stringify("v".concat(version).concat(versionTail))
            }, context.defines)));
            plugins.push(new ProvidePlugin(context.provides));
            /***********************
             * 多入口配置
             */

            fnBuildHTML(context, ENV.env).forEach(function (line) {
              plugins.push(new HTMLWebpackPlugin(line));
            });

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}

==> hollow-cli-1.3.14.tgz: package/esm/mwMultiEntryHTML.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 24/08/2017 18:42.
 **************************************************/
import { CopyWebpackPlugin, DefinePlugin, ProvidePlugin, HTMLWebpackPlugin } from './plugins';
import { fnBuildCopyFiles, fnBuildExternals, fnBuildHTML } from './util';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var packageMap, plugins, ENV, version, versionTail;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            next();
            packageMap = context.packageMap, plugins = context.plugins, ENV = context.ENV;
            /***********************
             * copy文件到输出目录
             */

            plugins.push(new CopyWebpackPlugin(fnBuildCopyFiles(context.files)));
            /***********************
             * 配置忽略依赖
             */

            context.externals = fnBuildExternals(_objectSpread({}, context.files, context.externals));
            version = context.version || packageMap.version || '0.0.0';
            versionTail = ENV.isBeta ? '-beta' : ENV.isDevelopment ? '-dev' : '';
            plugins.push(new DefinePlugin(_objectSpread({
              VERSION: JSON.stringify(version),
              APPLICATION_VERSION: JSON.stringify("v".concat(version).concat(versionTail))
            }, context.defines)));
            plugins.push(new ProvidePlugin(context.provides));
            /***********************
             * 多入口配置
             */

            fnBuildHTML(context, ENV.env).forEach(function (line) {
              plugins.push(new HTMLWebpackPlugin(line));
            });

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}
